@@ -47,6 +47,9 @@ type Session struct {
 
 	// Key filepath for PostgreSQL server.
 	TLSKeyFile string `conf:"name=TLSKeyFile,optional"`
+
+	// CacheMode for PostgreSQL server.
+	CacheMode string `conf:"name=CacheMode,optional"`
 }
 
 // PluginOptions are options for PostgreSQL connection.
@@ -69,6 +72,9 @@ type PluginOptions struct {
 
 	// CustomQueriesPath is a full pathname of a directory containing *.sql files with custom queries.
 	CustomQueriesPath string `conf:"optional"`
+
+	// Default stores default connection parameter values from configuration file
+	Default Session `conf:"optional"`
 }
 
 // Configure implements the Configurator interface.
